@@ -297,7 +297,8 @@ options:
     description:
       - Set custom DNS search domains (Use dns_search with '' if you don't wish
         to set the search domain)
-    type: str
+    type: list
+    elements: str
     aliases:
       - dns_search_domains
   entrypoint:
@@ -736,15 +737,15 @@ options:
       - mounts
   network:
     description:
-      - Set the Network mode for the container
-        * bridge create a network stack on the default bridge
-        * none no networking
-        * container:<name|id> reuse another container's network stack
-        * host use the podman host network stack.
-        * <network-name>|<network-id> connect to a user-defined network
-        * ns:<path> path to a network namespace to join
-        * slirp4netns use slirp4netns to create a user network stack.
-          This is the default for rootless containers
+      - Set the Network mode for the container.
+      - I(bridge) - create a network stack on the default bridge.
+      - I(none) - no networking.
+      - I(container:<name|id>) - reuse another container's network stack.
+      - I(host) - use the podman host network stack.
+      - I(<network-name>|<network-id>) - connect to a user-defined network.
+      - I(ns:<path>) - path to a network namespace to join.
+      - I(slirp4netns) - use slirp4netns to create a user network stack.
+        This is the default for rootless containers.
     type: list
     elements: str
     aliases:
@@ -969,6 +970,9 @@ options:
     description:
       - Determines how to use the NOTIFY_SOCKET, as passed with systemd and Type=notify.
         Can be container, conmon, ignore.
+        For quadlets it can also be healthy to use the built in health checks, see
+        L(documentation,https://docs.podman.io/en/latest/markdown/podman-systemd.unit.5.html#notify-defaults-to-false)
+        for more details.
     type: str
   secrets:
     description:
