@@ -96,7 +96,7 @@ options:
             events:
                 type: list
                 elements: str
-                description: No description.
+                description: SNMP trap events.
                 choices:
                     - 'cpu-high'
                     - 'mem-low'
@@ -155,20 +155,27 @@ options:
                     - 'slbc'
                     - 'faz'
                     - 'power-supply'
+                    - 'ippool'
+                    - 'interface'
+                    - 'security_level_change'
+                    - 'cert-expiry'
+                    - 'dio'
             hosts:
                 type: list
                 elements: dict
-                description: No description.
+                description: Hosts.
                 suboptions:
-                    ha-direct:
+                    ha_direct:
+                        aliases: ['ha-direct']
                         type: str
-                        description: Deprecated, please rename it to ha_direct. Enable/disable direct management of HA cluster members.
+                        description: Enable/disable direct management of HA cluster members.
                         choices:
                             - 'disable'
                             - 'enable'
-                    host-type:
+                    host_type:
+                        aliases: ['host-type']
                         type: str
-                        description: Deprecated, please rename it to host_type. Control whether the SNMP manager sends SNMP queries, receives SNMP trap...
+                        description: Control whether the SNMP manager sends SNMP queries, receives SNMP traps, or both.
                         choices:
                             - 'any'
                             - 'query'
@@ -179,23 +186,41 @@ options:
                     ip:
                         type: str
                         description: IPv4 address of the SNMP manager
-                    source-ip:
+                    source_ip:
+                        aliases: ['source-ip']
                         type: str
-                        description: Deprecated, please rename it to source_ip. Source IPv4 address for SNMP traps.
+                        description: Source IPv4 address for SNMP traps.
+                    interface_select_method:
+                        aliases: ['interface-select-method']
+                        type: str
+                        description: Specify how to select outgoing interface to reach server.
+                        choices:
+                            - 'auto'
+                            - 'sdwan'
+                            - 'specify'
+                    interface:
+                        type: raw
+                        description: (list) Specify outgoing interface to reach server.
+                    vrf_select:
+                        aliases: ['vrf-select']
+                        type: int
+                        description: VRF ID used for connection to server.
             hosts6:
                 type: list
                 elements: dict
-                description: No description.
+                description: Hosts6.
                 suboptions:
-                    ha-direct:
+                    ha_direct:
+                        aliases: ['ha-direct']
                         type: str
-                        description: Deprecated, please rename it to ha_direct. Enable/disable direct management of HA cluster members.
+                        description: Enable/disable direct management of HA cluster members.
                         choices:
                             - 'disable'
                             - 'enable'
-                    host-type:
+                    host_type:
+                        aliases: ['host-type']
                         type: str
-                        description: Deprecated, please rename it to host_type. Control whether the SNMP manager sends SNMP queries, receives SNMP trap...
+                        description: Control whether the SNMP manager sends SNMP queries, receives SNMP traps, or both.
                         choices:
                             - 'any'
                             - 'query'
@@ -206,9 +231,25 @@ options:
                     ipv6:
                         type: str
                         description: SNMP manager IPv6 address prefix.
-                    source-ipv6:
+                    source_ipv6:
+                        aliases: ['source-ipv6']
                         type: str
-                        description: Deprecated, please rename it to source_ipv6. Source IPv6 address for SNMP traps.
+                        description: Source IPv6 address for SNMP traps.
+                    interface:
+                        type: raw
+                        description: (list) Specify outgoing interface to reach server.
+                    interface_select_method:
+                        aliases: ['interface-select-method']
+                        type: str
+                        description: Specify how to select outgoing interface to reach server.
+                        choices:
+                            - 'auto'
+                            - 'sdwan'
+                            - 'specify'
+                    vrf_select:
+                        aliases: ['vrf-select']
+                        type: int
+                        description: VRF ID used for connection to server.
             id:
                 type: int
                 description: Community ID.
@@ -216,21 +257,25 @@ options:
             name:
                 type: str
                 description: Community name.
-            query-v1-port:
+            query_v1_port:
+                aliases: ['query-v1-port']
                 type: int
-                description: Deprecated, please rename it to query_v1_port. SNMP v1 query port
-            query-v1-status:
+                description: SNMP v1 query port
+            query_v1_status:
+                aliases: ['query-v1-status']
                 type: str
-                description: Deprecated, please rename it to query_v1_status. Enable/disable SNMP v1 queries.
+                description: Enable/disable SNMP v1 queries.
                 choices:
                     - 'disable'
                     - 'enable'
-            query-v2c-port:
+            query_v2c_port:
+                aliases: ['query-v2c-port']
                 type: int
-                description: Deprecated, please rename it to query_v2c_port. SNMP v2c query port
-            query-v2c-status:
+                description: SNMP v2c query port
+            query_v2c_status:
+                aliases: ['query-v2c-status']
                 type: str
-                description: Deprecated, please rename it to query_v2c_status. Enable/disable SNMP v2c queries.
+                description: Enable/disable SNMP v2c queries.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -240,36 +285,43 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            trap-v1-lport:
+            trap_v1_lport:
+                aliases: ['trap-v1-lport']
                 type: int
-                description: Deprecated, please rename it to trap_v1_lport. SNMP v1 trap local port
-            trap-v1-rport:
+                description: SNMP v1 trap local port
+            trap_v1_rport:
+                aliases: ['trap-v1-rport']
                 type: int
-                description: Deprecated, please rename it to trap_v1_rport. SNMP v1 trap remote port
-            trap-v1-status:
+                description: SNMP v1 trap remote port
+            trap_v1_status:
+                aliases: ['trap-v1-status']
                 type: str
-                description: Deprecated, please rename it to trap_v1_status. Enable/disable SNMP v1 traps.
+                description: Enable/disable SNMP v1 traps.
                 choices:
                     - 'disable'
                     - 'enable'
-            trap-v2c-lport:
+            trap_v2c_lport:
+                aliases: ['trap-v2c-lport']
                 type: int
-                description: Deprecated, please rename it to trap_v2c_lport. SNMP v2c trap local port
-            trap-v2c-rport:
+                description: SNMP v2c trap local port
+            trap_v2c_rport:
+                aliases: ['trap-v2c-rport']
                 type: int
-                description: Deprecated, please rename it to trap_v2c_rport. SNMP v2c trap remote port
-            trap-v2c-status:
+                description: SNMP v2c trap remote port
+            trap_v2c_status:
+                aliases: ['trap-v2c-status']
                 type: str
-                description: Deprecated, please rename it to trap_v2c_status. Enable/disable SNMP v2c traps.
+                description: Enable/disable SNMP v2c traps.
                 choices:
                     - 'disable'
                     - 'enable'
-            mib-view:
+            mib_view:
+                aliases: ['mib-view']
                 type: str
-                description: Deprecated, please rename it to mib_view. SNMP access control MIB view.
+                description: SNMP access control MIB view.
             vdoms:
                 type: raw
-                description: (list) No description.
+                description: (list) SNMP access control VDOMs.
 '''
 
 EXAMPLES = '''
@@ -400,21 +452,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/devprof/{devprof}/system/snmp/community'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/devprof/{devprof}/system/snmp/community/{community}'
-    ]
-
     url_params = ['adom', 'devprof']
     module_primary_key = 'id'
     module_arg_spec = {
@@ -436,7 +481,7 @@ def main():
                         'ips-fail-open', 'load-balance-real-server-down', 'device-new', 'enter-intf-bypass', 'exit-intf-bypass', 'per-cpu-high',
                         'power-blade-down', 'confsync_failure', 'dhcp', 'pool-usage', 'power-redundancy-degrade', 'power-redundancy-failure',
                         'ospf-nbr-state-change', 'ospf-virtnbr-state-change', 'disk-failure', 'disk-overload', 'faz-main-failover', 'faz-alt-failover',
-                        'slbc', 'faz', 'power-supply'
+                        'slbc', 'faz', 'power-supply', 'ippool', 'interface', 'security_level_change', 'cert-expiry', 'dio'
                     ],
                     'elements': 'str'
                 },
@@ -452,7 +497,10 @@ def main():
                         },
                         'id': {'v_range': [['6.0.0', '6.2.5'], ['6.2.7', '6.4.1'], ['6.4.3', '']], 'type': 'int'},
                         'ip': {'v_range': [['6.0.0', '6.2.5'], ['6.2.7', '6.4.1'], ['6.4.3', '']], 'type': 'str'},
-                        'source-ip': {'v_range': [['6.0.0', '6.2.5'], ['6.2.7', '6.4.1'], ['6.4.3', '']], 'type': 'str'}
+                        'source-ip': {'v_range': [['6.0.0', '6.2.5'], ['6.2.7', '6.4.1'], ['6.4.3', '']], 'type': 'str'},
+                        'interface-select-method': {'v_range': [['7.6.0', '']], 'choices': ['auto', 'sdwan', 'specify'], 'type': 'str'},
+                        'interface': {'v_range': [['7.6.0', '']], 'type': 'raw'},
+                        'vrf-select': {'v_range': [['7.6.2', '']], 'type': 'int'}
                     },
                     'elements': 'dict'
                 },
@@ -468,7 +516,10 @@ def main():
                         },
                         'id': {'v_range': [['6.0.0', '6.2.5'], ['6.2.7', '6.4.1'], ['6.4.3', '']], 'type': 'int'},
                         'ipv6': {'v_range': [['6.0.0', '6.2.5'], ['6.2.7', '6.4.1'], ['6.4.3', '']], 'type': 'str'},
-                        'source-ipv6': {'v_range': [['6.0.0', '6.2.5'], ['6.2.7', '6.4.1'], ['6.4.3', '']], 'type': 'str'}
+                        'source-ipv6': {'v_range': [['6.0.0', '6.2.5'], ['6.2.7', '6.4.1'], ['6.4.3', '']], 'type': 'str'},
+                        'interface': {'v_range': [['7.6.0', '']], 'type': 'raw'},
+                        'interface-select-method': {'v_range': [['7.6.0', '']], 'choices': ['auto', 'sdwan', 'specify'], 'type': 'str'},
+                        'vrf-select': {'v_range': [['7.6.2', '']], 'type': 'int'}
                     },
                     'elements': 'dict'
                 },
@@ -488,7 +539,6 @@ def main():
                 'mib-view': {'v_range': [['7.2.0', '']], 'type': 'str'},
                 'vdoms': {'v_range': [['7.2.0', '']], 'type': 'raw'}
             }
-
         }
     }
 
@@ -497,17 +547,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'devprof_system_snmp_community'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
