@@ -61,3 +61,5 @@ class GADPairValidateMSG(Enum):
     NO_GAD_PAIR_FOUND_FOR_INPUTS = (
         "Could not find GAD pair for the input parameters supplied."
     )
+    NO_REMOTE_HGS_FOUND = "Specified host groups not found on secondary storage."
+    NO_REMOTE_ISCSI_FOUND = "Specified iSCSI targets not found on secondary storage."
